'''
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
# Node
Module | `node.py`

Daniel Bakas Amuchastegui\
March 16, 2020

Copyright © Semantyk 2020. All rights reserved.\
–––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
'''

__all__ = ['Node']

class Node(object):
    __slots__ = ()
